@@ -17,11 +17,6 @@ module VagrantPlugins
         VagrantPlugins::CloudCommand::AuthCommand::Command::Login
       end
 
-      action_hook(:cloud_authenticated_boxes, :authenticate_box_url) do |hook|
-        require_relative "middleware/add_authentication"
-        hook.prepend(AddAuthentication)
-      end
-
       protected
 
       def self.init!
