@@ -42,8 +42,8 @@ module VagrantPlugins
       end
 
       guest_capability(:bsd, :mount_virtualbox_shared_folder) do
-        require_relative "cap/virtualbox"
-        Cap::VirtualBox
+        require_relative "cap/mount_virtualbox_shared_folder"
+        Cap::MountVirtualBoxSharedFolder
       end
 
       guest_capability(:bsd, :remove_public_key) do
