@@ -7,6 +7,7 @@ require "vagrant/action/builtin/mixin_synced_folders"
 require "vagrant/config/v2/util"
 require "vagrant/util/platform"
 require "vagrant/util/presence"
+require "vagrant/util/experimental"
 
 require File.expand_path("../vm_provisioner", __FILE__)
 require File.expand_path("../vm_subvm", __FILE__)
@@ -20,6 +21,7 @@ module VagrantPlugins
 
       attr_accessor :allowed_synced_folder_types
       attr_accessor :base_mac
+      attr_accessor :base_address
       attr_accessor :boot_timeout
       attr_accessor :box
       attr_accessor :ignore_box_vagrantfile
@@ -50,6 +52,7 @@ module VagrantPlugins
 
         @allowed_synced_folder_types   = UNSET_VALUE
         @base_mac                      = UNSET_VALUE
+        @base_address                  = UNSET_VALUE
         @boot_timeout                  = UNSET_VALUE
         @box                           = UNSET_VALUE
         @ignore_box_vagrantfile        = UNSET_VALUE
@@ -329,7 +332,19 @@ module VagrantPlugins
         end
 
         if !prov
-          prov = VagrantConfigProvisioner.new(name, type.to_sym)
+          if options.key?(:before)
+            before = options.delete(:before)
+          end
+          if options.key?(:after)
+            after = options.delete(:after)
+          end
+
+          if Vagrant::Util::Experimental.feature_enabled?("dependency_provisioners")
+            opts = {before: before, after: after}
+            prov = VagrantConfigProvisioner.new(name, type.to_sym, opts)
+          else
+            prov = VagrantConfigProvisioner.new(name, type.to_sym)
+          end
           @provisioners << prov
         end
 
@@ -377,6 +392,7 @@ module VagrantPlugins
         # Defaults
         @allowed_synced_folder_types = nil if @allowed_synced_folder_types == UNSET_VALUE
         @base_mac = nil if @base_mac == UNSET_VALUE
+        @base_address = nil if @base_address == UNSET_VALUE
         @boot_timeout = 300 if @boot_timeout == UNSET_VALUE
         @box = nil if @box == UNSET_VALUE
         @ignore_box_vagrantfile = false if @ignore_box_vagrantfile == UNSET_VALUE
@@ -493,7 +509,7 @@ module VagrantPlugins
 
             line = "(unknown)"
             if e.backtrace && e.backtrace[0]
-              line = e.backtrace[0].split(":")[1]
+              line = e.backtrace.first.slice(0, e.backtrace.first.rindex(':')).rpartition(':').last
             end
 
             raise Vagrant::Errors::VagrantfileLoadError,
@@ -757,6 +773,11 @@ module VagrantPlugins
             next
           end
 
+          provisioner_errors = vm_provisioner.validate(machine, @provisioners)
+          if provisioner_errors
+            errors = Vagrant::Config::V2::Util.merge_errors(errors, provisioner_errors)
+          end
+
           if vm_provisioner.config
             provisioner_errors = vm_provisioner.config.validate(machine)
             if provisioner_errors
