@@ -411,38 +411,6 @@ describe Vagrant::Machine do
         expect(subject.ui).to_not have_received(:warn)
       end
     end
-
-    context "with the vagrant-triggers community plugin" do
-      it "should not call the internal trigger functions if installed" do
-        action_name = :destroy
-        callable    = lambda { |_env| }
-
-        allow(provider).to receive(:action).with(action_name).and_return(callable)
-
-        # The first call here is to allow the environment to setup with attempting
-        # to load a plugin that does not exist
-        expect(Vagrant::Plugin::Manager.instance).to receive(:installed_plugins)
-          .and_return({})
-
-        expect(Vagrant::Plugin::Manager.instance).to receive(:installed_plugins)
-          .and_return({"vagrant-triggers"=>"stuff"})
-
-        expect(instance.instance_variable_get(:@triggers)).not_to receive(:fire_triggers)
-        instance.action(action_name)
-      end
-
-      it "should call the internal trigger functions if not installed" do
-        action_name = :destroy
-        callable    = lambda { |_env| }
-
-        allow(provider).to receive(:action).with(action_name).and_return(callable)
-        allow(Vagrant::Plugin::Manager.instance).to receive(:installed_plugins)
-          .and_return({})
-
-        expect(instance.instance_variable_get(:@triggers)).to receive(:fire_triggers).twice
-        instance.action(action_name)
-      end
-    end
   end
 
   describe "#action_raw" do
@@ -944,4 +912,62 @@ describe Vagrant::Machine do
       expect(subject.ui).to_not equal(ui)
     end
   end
+
+  describe "#reload" do
+    context "when ID is unset and id file does not exist" do
+      it "should remain nil" do
+        expect(subject.id).to be_nil
+        instance.reload
+        expect(subject.id).to be_nil
+      end
+    end
+
+    context "when id file is set" do
+      let(:id_content) { "test-machine-id" }
+
+      before do
+        id_file = subject.data_dir.join("id")
+        File.write(id_file.to_s, id_content)
+      end
+
+      it "should update the machine id" do
+        expect(subject.id).to be_nil
+        instance.reload
+        expect(subject.id).to eq(id_content)
+      end
+
+      it "should notify of the id change when provider is set" do
+        expect(provider).to receive(:machine_id_changed)
+        instance.reload
+      end
+
+      context "when id file content includes whitespace" do
+        let(:id_content) { "   test-machine-id\n" }
+
+        it "should remove all whitespace" do
+          instance.reload
+          expect(instance.id).to eq("test-machine-id")
+        end
+      end
+
+      context "when id file content is all whitespace" do
+        let(:id_content) { "\0\0\0\0\0\0" }
+
+        it "should not update the id" do
+          expect(instance.id).to be_nil
+          instance.reload
+          expect(instance.id).to be_nil
+        end
+      end
+
+      context "when id is already set to value in id file" do
+        it "should not notify of id change" do
+          instance.instance_variable_set(:@id, id_content)
+          expect(provider).not_to receive(:machine_id_changed)
+          instance.reload
+          expect(instance.id).to eq(id_content)
+        end
+      end
+    end
+  end
 end
